package org.acme.scheduler;

import io.quarkus.test.junit.QuarkusIntegrationTest;

@QuarkusIntegrationTest
public class CountResourceIT extends CountResourceTest {

}